### Name: boolfun-package
### Title: Cryptographic Boolean Functions
### Aliases: boolfun-package boolfun
### Keywords: package math logic

### ** Examples


    # Functions are defined by their truth tables (string or integer vector).
    f <- BooleanFunction( "00100111" )
    g <- BooleanFunction(c(0,1,1,0,1,0,0,1))
    h <- BooleanFunction( c(tt(f), tt(g)) ) # concatenation

    # You can print information on the function as follows.
    print ( h )     # Prints "Boolean function with 4 variables.".
    print ( tt(h) ) # Prints the truth table.

    # Note that the methods can be called 'object$method()' or 'method(object)': 
    print(paste(  "f has (deg,ai,nl,res) = (", f$deg(),f$ai(),f$nl(),f$res(),")"  ))
    print(paste(  "h has (deg,ai,nl,res) = (", deg(h), ai(h), nl(h), res(h), ")"  ))

    # Random Boolean functions   
    randomBFs <- c()
    data <- c( "degree", "algebraic immunity", "nonlinearity", "resiliency" )
    for( i in 1:500 ) {
        randomTT <- round(runif(2^5, 0,1))
        randomBF <- BooleanFunction(randomTT)
        data <- rbind( data, c(
                deg(randomBF), ai(randomBF),
                nl(randomBF), res(randomBF)))
    }
    print(data)



